@@ -1,19 +1,47 @@
+# -*- coding: utf-8 -*-
 #
 # Univention Samba
 #  listener module: manages samba share configuration
 #
-# SPDX-FileCopyrightText: 2001-2026 Univention GmbH
-# SPDX-License-Identifier: AGPL-3.0-only
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# Copyright 2001-2023 Univention GmbH
+#
+# https://www.univention.de/
+#
+# All rights reserved.
+#
+# The source code of this program is made available
+# under the terms of the GNU Affero General Public License version 3
+# (GNU AGPL V3) as published by the Free Software Foundation.
+#
+# Binary versions of this program provided by Univention to you as
+# well as other copyrighted, protected or trademarked materials like
+# Logos, graphics, fonts, specific documentations and configurations,
+# cryptographic keys etc. are subject to a license agreement between
+# you and Univention and not subject to the GNU AGPL V3.
+#
+# In the case you use this program under the terms of the GNU AGPL V3,
+# the program is provided in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public
+# License with the Debian GNU/Linux or Univention distribution in file
+# /usr/share/common-licenses/AGPL-3; if not, see
+# <https://www.gnu.org/licenses/>.
 
-from __future__ import annotations
+from __future__ import absolute_import, annotations, print_function
 
-import functools
-import operator
 import os
-import pickle  # noqa: S403
 import re
 import subprocess
-from urllib.parse import quote
+from typing import Dict, List
+
+from six.moves import cPickle as pickle
+from six.moves.urllib_parse import quote
 
 import univention.debug as ud
 import univention.lib.listenerSharePath
@@ -40,10 +68,12 @@ def _validate_smb_share_name(name: str) -> bool:
     if not name or len(name) > 80:
         return False
     illegal_chars = set('\\/[]:|<>+=;,*?"' + ''.join(map(chr, range(0x1F + 1))))
-    return not set(str(name)) & illegal_chars
+    if set(str(name)) & illegal_chars:
+        return False
+    return True
 
 
-def handler(dn: str, new: dict[str, list[bytes]], old: dict[str, list[bytes]], command: str) -> None:
+def handler(dn: str, new: Dict[str, List[bytes]], old: Dict[str, List[bytes]], command: str) -> None:
     configRegistry.load()
     interfaces = Interfaces(configRegistry)
 
@@ -179,6 +209,8 @@ def handler(dn: str, new: dict[str, list[bytes]], old: dict[str, list[bytes]], c
             samba4_ntacl_backend = configRegistry.get('samba4/ntacl/backend', 'native')
             if samba4_ntacl_backend == 'native':
                 vfs_objects.append(b'acl_xattr')
+                if configRegistry.is_true('samba/vfs/acl_xattr/ignore_system_acls', False):
+                    print('acl_xattr:ignore system acls = yes')  # FIXME: file=fp, broken since git:35decbd0e8f
             elif samba4_ntacl_backend == 'tdb':
                 vfs_objects.append(b'acl_tdb')
 
@@ -210,7 +242,7 @@ def handler(dn: str, new: dict[str, list[bytes]], old: dict[str, list[bytes]], c
             if not os.path.exists('/etc/samba/shares.conf'):
                 run_ucs_commit = True
             fp = open('/etc/samba/shares.conf.temp', 'w')
-            print('# Warning: This file is auto-generated and will be overwritten by \n#          univention-directory-listener module. \n#          Please edit the following file instead: \n#          /etc/samba/local.conf \n  \n# Warnung: Diese Datei wurde automatisch generiert und wird durch ein \n#          univention-directory-listener Modul überschrieben werden. \n#          Ergänzungen können an folgende Datei vorgenommen werden: \n# \n#          /etc/samba/local.conf \n#', file=fp)
+            print('# Warning: This file is auto-generated and will be overwritten by \n#          univention-directory-listener module. \n#          Please edit the following file instead: \n#          /etc/samba/local.conf \n  \n# Warnung: Diese Datei wurde automatisch generiert und wird durch ein \n#          univention-directory-listener Module überschrieben werden. \n#          Ergänzungen können an folgender Datei vorgenommen werden: \n# \n#          /etc/samba/local.conf \n#', file=fp)
 
             for f in os.listdir('/etc/samba/shares.conf.d'):
                 print('include = %s' % _quote(os.path.join('/etc/samba/shares.conf.d', f)), file=fp)
@@ -233,9 +265,9 @@ def handler(dn: str, new: dict[str, list[bytes]], old: dict[str, list[bytes]], c
             prev_aces = set()
             new_aces = set()
             if 'univentionShareSambaBaseDirAppendACL' in old:
-                prev_aces = set(functools.reduce(operator.iadd, [RE_ACE.findall(acl.decode('UTF-8')) for acl in old['univentionShareSambaBaseDirAppendACL']], []))
+                prev_aces = set(sum([RE_ACE.findall(acl.decode('UTF-8')) for acl in old['univentionShareSambaBaseDirAppendACL']], []))
             if 'univentionShareSambaBaseDirAppendACL' in new:
-                new_aces = set(functools.reduce(operator.iadd, [RE_ACE.findall(acl.decode('UTF-8')) for acl in new['univentionShareSambaBaseDirAppendACL']], []))
+                new_aces = set(sum([RE_ACE.findall(acl.decode('UTF-8')) for acl in new['univentionShareSambaBaseDirAppendACL']], []))
 
             if (new_aces and new_aces != prev_aces) or (prev_aces and not new_aces):
                 # if old != new -> delete everything from old!
